@@ -1099,42 +1099,42 @@ static GtkRadioActionEntry core_style_entries[] = {
 
 	{ "style-h1",
 	  NULL,
-	  N_("Header _1"),
+	  N_("Heading _1"),
 	  "<Control>1",
 	  NULL,
 	  E_CONTENT_EDITOR_BLOCK_FORMAT_H1 },
 
 	{ "style-h2",
 	  NULL,
-	  N_("Header _2"),
+	  N_("Heading _2"),
 	  "<Control>2",
 	  NULL,
 	  E_CONTENT_EDITOR_BLOCK_FORMAT_H2 },
 
 	{ "style-h3",
 	  NULL,
-	  N_("Header _3"),
+	  N_("Heading _3"),
 	  "<Control>3",
 	  NULL,
 	  E_CONTENT_EDITOR_BLOCK_FORMAT_H3 },
 
 	{ "style-h4",
 	  NULL,
-	  N_("Header _4"),
+	  N_("Heading _4"),
 	  "<Control>4",
 	  NULL,
 	  E_CONTENT_EDITOR_BLOCK_FORMAT_H4 },
 
 	{ "style-h5",
 	  NULL,
-	  N_("Header _5"),
+	  N_("Heading _5"),
 	  "<Control>5",
 	  NULL,
 	  E_CONTENT_EDITOR_BLOCK_FORMAT_H5 },
 
 	{ "style-h6",
 	  NULL,
-	  N_("Header _6"),
+	  N_("Heading _6"),
 	  "<Control>6",
 	  NULL,
 	  E_CONTENT_EDITOR_BLOCK_FORMAT_H6 },
