@@ -33,6 +33,8 @@
 #include <em-format/e-mail-part-attachment.h>
 #include <em-format/e-mail-part-utils.h>
 
+#include "shell/e-shell-utils.h"
+
 #include "e-cid-request.h"
 #include "e-http-request.h"
 #include "e-mail-display-popup-extension.h"
@@ -84,6 +86,7 @@ struct _EMailDisplayPrivate {
 	GHashTable *skipped_remote_content_sites;
 
 	guint web_extension_headers_collapsed_signal_id;
+	guint web_extension_mail_part_appeared_signal_id;
 
 	GtkAllocation attachment_popup_position;
 };
@@ -532,6 +535,41 @@ headers_collapsed_signal_cb (GDBusConnection *connection,
 	e_mail_display_set_headers_collapsed (display, expanded);
 }
 
+static void
+mail_display_mail_part_appeared_signal_cb (GDBusConnection *connection,
+					   const gchar *sender_name,
+					   const gchar *object_path,
+					   const gchar *interface_name,
+					   const gchar *signal_name,
+					   GVariant *parameters,
+					   gpointer user_data)
+{
+	EMailDisplay *display = user_data;
+	const gchar *part_id = NULL;
+	guint64 page_id = 0;
+	EMailPart *part;
+
+	if (g_strcmp0 (signal_name, "MailPartAppeared") != 0)
+		return;
+
+	g_return_if_fail (E_IS_MAIL_DISPLAY (display));
+
+	if (!parameters || !display->priv->part_list)
+		return;
+
+	g_variant_get (parameters, "(t&s)", &page_id, &part_id);
+
+	if (!part_id || !*part_id || page_id != webkit_web_view_get_page_id (WEBKIT_WEB_VIEW (display)))
+		return;
+
+	part = e_mail_part_list_ref_part (display->priv->part_list, part_id);
+	if (part && g_strcmp0 (e_mail_part_get_id (part), part_id) == 0) {
+		e_mail_part_bind_dom_element (part, E_WEB_VIEW (display), page_id, part_id);
+	}
+
+	g_clear_object (&part);
+}
+
 static void
 setup_dom_bindings (EMailDisplay *display)
 {
@@ -555,6 +593,21 @@ setup_dom_bindings (EMailDisplay *display)
 					NULL);
 		}
 
+		if (display->priv->web_extension_mail_part_appeared_signal_id == 0) {
+			display->priv->web_extension_mail_part_appeared_signal_id =
+				g_dbus_connection_signal_subscribe (
+					g_dbus_proxy_get_connection (web_extension),
+					g_dbus_proxy_get_name (web_extension),
+					E_WEB_EXTENSION_INTERFACE,
+					"MailPartAppeared",
+					E_WEB_EXTENSION_OBJECT_PATH,
+					NULL,
+					G_DBUS_SIGNAL_FLAGS_NONE,
+					mail_display_mail_part_appeared_signal_cb,
+					display,
+					NULL);
+		}
+
 		e_util_invoke_g_dbus_proxy_call_with_error_check (
 			web_extension,
 			"EMailDisplayBindDOM",
@@ -1089,19 +1142,25 @@ mail_display_attachment_removed_cb (EAttachmentStore *store,
 	g_hash_table_remove (display->priv->attachment_flags, attachment);
 }
 
+typedef struct _MailElementExistsData {
+	EWebView *web_view;
+	EMailPart *part;
+} MailElementExistsData;
+
 static void
 mail_element_exists_cb (GObject *source_object,
                         GAsyncResult *result,
                         gpointer user_data)
 {
 	GDBusProxy *web_extension;
-	EMailPart *part = user_data;
+	MailElementExistsData *meed = user_data;
 	gboolean element_exists = FALSE;
 	GVariant *result_variant;
 	guint64 page_id;
 	GError *error = NULL;
 
 	g_return_if_fail (G_IS_DBUS_PROXY (source_object));
+	g_return_if_fail (meed != NULL);
 
 	web_extension = G_DBUS_PROXY (source_object);
 
@@ -1113,12 +1172,14 @@ mail_element_exists_cb (GObject *source_object,
 
 	if (element_exists)
 		e_mail_part_bind_dom_element (
-			part,
-			web_extension,
+			meed->part,
+			meed->web_view,
 			page_id,
-			e_mail_part_get_id (part));
+			e_mail_part_get_id (meed->part));
 
-	g_object_unref (part);
+	g_object_unref (meed->web_view);
+	g_object_unref (meed->part);
+	g_free (meed);
 
 	if (error)
 		g_dbus_error_strip_remote_error (error);
@@ -1153,6 +1214,7 @@ mail_parts_bind_dom (EMailDisplay *display)
 	head = g_queue_peek_head_link (&queue);
 
 	for (link = head; link != NULL; link = g_list_next (link)) {
+		MailElementExistsData *meed;
 		EMailPart *part = E_MAIL_PART (link->data);
 		const gchar *part_id;
 
@@ -1162,6 +1224,10 @@ mail_parts_bind_dom (EMailDisplay *display)
 
 		e_mail_part_web_view_loaded (part, web_view);
 
+		meed = g_new0 (MailElementExistsData, 1);
+		meed->web_view = g_object_ref (web_view);
+		meed->part = g_object_ref (part);
+
 		g_dbus_proxy_call (
 			web_extension,
 			"ElementExists",
@@ -1174,7 +1240,7 @@ mail_parts_bind_dom (EMailDisplay *display)
 			-1,
 			NULL,
 			mail_element_exists_cb,
-			g_object_ref (part));
+			meed);
 	}
 
 	while (!g_queue_is_empty (&queue))
@@ -1348,6 +1414,17 @@ mail_display_dispose (GObject *object)
 		priv->web_extension_headers_collapsed_signal_id = 0;
 	}
 
+	if (priv->web_extension_mail_part_appeared_signal_id > 0) {
+		GDBusProxy *web_extension = e_web_view_get_web_extension_proxy (E_WEB_VIEW (object));
+
+		if (web_extension != NULL) {
+			g_dbus_connection_signal_unsubscribe (
+				g_dbus_proxy_get_connection (web_extension),
+				priv->web_extension_mail_part_appeared_signal_id);
+		}
+		priv->web_extension_mail_part_appeared_signal_id = 0;
+	}
+
 	if (priv->attachment_store) {
 		/* To have called the mail_display_attachment_removed_cb() before it's disconnected */
 		e_attachment_store_remove_all (priv->attachment_store);
@@ -1817,6 +1894,19 @@ e_mail_display_test_change_and_update_fonts_cb (EMailDisplay *mail_display,
 	}
 }
 
+static void
+mail_display_web_process_crashed_cb (EMailDisplay *display)
+{
+	EAlertSink *alert_sink;
+
+	g_return_if_fail (E_IS_MAIL_DISPLAY (display));
+
+	/* Cannot use the EWebView, because it places the alerts inside itself */
+	alert_sink = e_shell_utils_find_alternate_alert_sink (GTK_WIDGET (display));
+	if (alert_sink)
+		e_alert_submit (alert_sink, "mail:webkit-web-process-crashed", NULL);
+}
+
 static void
 e_mail_display_class_init (EMailDisplayClass *class)
 {
@@ -1963,6 +2053,10 @@ e_mail_display_init (EMailDisplay *display)
 	display->priv->force_image_load = FALSE;
 	display->priv->scheduled_reload = 0;
 
+	g_signal_connect (
+		display, "web-process-crashed",
+		G_CALLBACK (mail_display_web_process_crashed_cb), NULL);
+
 	g_signal_connect (
 		display, "decide-policy",
 		G_CALLBACK (decide_policy_cb), NULL);
