@@ -77,12 +77,17 @@ e_shell_run_open_dialog (EShell *shell,
 
 	gtk_file_chooser_set_local_only (file_chooser, FALSE);
 
+	e_util_load_file_chooser_folder (file_chooser);
+
 	/* Allow further customizations before running the dialog. */
 	if (customize_func != NULL)
 		customize_func (dialog, customize_data);
 
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		e_util_save_file_chooser_folder (file_chooser);
+
 		chosen_file = gtk_file_chooser_get_file (file_chooser);
+	}
 
 	gtk_widget_destroy (dialog);
 
@@ -204,12 +209,17 @@ e_shell_run_save_dialog (EShell *shell,
 		g_strfreev (flts);
 	}
 
+	e_util_load_file_chooser_folder (file_chooser);
+
 	/* Allow further customizations before running the dialog. */
 	if (customize_func != NULL)
 		customize_func (dialog, customize_data);
 
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		e_util_save_file_chooser_folder (file_chooser);
+
 		chosen_file = gtk_file_chooser_get_file (file_chooser);
+	}
 
 	gtk_widget_destroy (dialog);
 
@@ -448,3 +458,28 @@ e_shell_utils_run_help_contents (EShell *shell)
 	e_display_help (window, NULL);
 #endif
 }
+
+/**
+ * e_shell_utils_find_alternate_alert_sink:
+ * @widget: a #GtkWidget for which to do the search
+ *
+ * Search an alternate #EAlertSink in the widget hierarchy up-wards
+ * from the @widget (skipping the @widget itself).
+ *
+ * Returns: (nullable) (transfer none): an alert sink, different than @widget,
+ *    or %NULL, when none found
+ *
+ * Since: 3.24
+ **/
+EAlertSink *
+e_shell_utils_find_alternate_alert_sink (GtkWidget *widget)
+{
+	g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
+
+	while (widget = gtk_widget_get_parent (widget), widget) {
+		if (E_IS_ALERT_SINK (widget))
+			return E_ALERT_SINK (widget);
+	}
+
+	return NULL;
+}
